Exploratory Data Analysis
****************************

The purpose of this module is to quickly explore the data with as many plots as possible.

.. autoclass:: ai4water.eda.EDA
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__
   .. automethod:: __call__
